await_deposits

Function await_deposits 

pub(crate) async fn await_deposits(
    client: &Client,
    position: EventLogId,
    receives: usize,
    min_balance: u64,
) -> Result<()>
Waits for receives deposits to be claimed (starting from event log position) and then asserts the client balance reached at least min_balance sats.

On fedimint-cli versions without await-receive (<= 0.11), falls back to polling the balance like the test used to.