pub(crate) async fn await_receive(
client: &Client,
position: EventLogId,
) -> Result<EventLogId>Expand description
Waits for the next receive recorded at or after position to be claimed,
returning the event log position to use for the following wait.